@@ -138,19 +138,25 @@ int store_db(struct box *box1) {
   FILE *f1;
   char s2[Blen+1] = "./db/", s3[Blen+1];
   int i2, dx, dy;
+  unsigned c_out;
   pix b;	/* temporary mini page */
 
   if( JOB->cfg.db_path ) strncpy(s2,JOB->cfg.db_path,Blen-1);
   i2=strlen(s2);
+  
+  /* add (first) char and time to the file name for better debugging */
+ 
+  /* decide between 7bit ASCII and UTF8-char or string */
+  c_out =  ((box1->num_ac && box1->tas[0]) ?
+         (unsigned char )box1->tas[0][0] /* char  */ :
+                         box1->c         /* wchar */);
+  /* (unsigned int)((         char)0x80) = 0xffffff80 */
+  /* (unsigned int)((unsigned char)0x80) = 0x00000080 */
  
   /* name generation can cause problems, if called twice within a second */
-  if (box1->num_ac && box1->tas[0])
-    sprintf(s3,"db_%04x_%lu.pbm", (unsigned int)box1->tas[0][0],
-                                  (unsigned long)time(NULL));
-  else
-    sprintf(s3,"db_%04x_%lu.pbm", (unsigned int)box1->c,
-                                  (unsigned long)time(NULL));
+  sprintf(s3,"db_%04x_%08lx.pbm", c_out, (unsigned long)time(NULL));
   /* ToDo: the file name may be not unique */
+  
   strncpy(s2+i2,"db.lst",Blen-i2);s2[Blen]=0;
   f1 = fopen(s2, "a");
   if (!f1) {
@@ -162,7 +168,9 @@ int store_db(struct box *box1) {
   /* ToDo: store the vector list instead of the pixelarray */
   
   if (JOB->cfg.verbose)
-    fprintf(stderr, "store_db: add file %s to database\n#",s3);
+    fprintf(stderr, "store_db: add file %s to database (nac=%d c=%04x)"
+      "\n#",s3, box1->num_ac, c_out);
+
   dx=box1->x1-box1->x0+1;
   dy=box1->y1-box1->y0+1;
   b.p = (unsigned char *) malloc( dx * dy );
@@ -419,6 +427,7 @@ wchar_t ocr_db(struct box *box1) {
       int u0, u1;  /* define UTF8-start sequences, u0=0bits u1=1bits */
       u0=       1<<(7-dd);       /* compute start byte from UTF8-length */
       u1=255&~((1<<(8-dd))-1);
+      /* count number of following 10xxxxxx bytes to i */
       for (i=1;i<dd;i++) if ((buf[i]&0xc0)!=0x80) break; /* 10xxxxxx */
       if (i==dd && (buf[0]&(u0|u1))==u1) { utf8_ok=1;
         c=buf[0]&(u0-1);                                 /* 11..0x.. */
