@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2008 Joerg Schulenburg
+Copyright (C) 2000-2009 Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -292,11 +292,10 @@ void store_boxtree_lines(int mo) {
           /* output glued chars or ... (?) Jan08 */
           buffer=append_to_line(buffer,box2->tas[0],&len);
           j+=strlen(box2->tas[0]);
-        } else {  /* leave string empty? */
-          /*
-           buffer=
-            append_to_line(buffer,decode(cc,JOB->cfg.out_format),&len);
-          */
+        } else {  /* ToDo: leave string empty? set placeholder per option */
+           /* output dummy string to mark UNKNOWN */
+           if(JOB->cfg.unrec_marker[0])
+             buffer = append_to_line(buffer, JOB->cfg.unrec_marker, &len);
         }
       }
       if (JOB->cfg.out_format==XML) {
