@@ -165,10 +165,12 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if(   loop(bp,dx/4,3*dy/10,dy,cs,1,DO)>0 ) // check start
       if(   loop(bp,dx-2,3*dy/4 ,dy,cs,1,UP)>0 ) // check end
       if( num_cross(dx/4,dx-2,3*dy/10,3*dy/4,bp,cs)==1 ) Break; // connected?
+      MSG(fprintf(stderr,"~S ad=%d",ad);)
       
       // small fat s is very similar to rounded serif 5
       //   but has a fat diagonal arrea (Oct08 JS)
       if ( num_cross(dx/8,dx-1-dx/8,3*dy/10,3*dy/4,bp,cs)==1 ) ad=98*ad/100;
+      MSG(fprintf(stderr,"~S ad=%d",ad);)
 
       if( dy>17 && dx>9 ) /* S */
       if(   loop(bp,   0,dy/2   ,dx,cs,0,RI)<dx/2
@@ -177,10 +179,12 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if(   loop(bp,dx-2,2*dy/3 ,dy,cs,1,UP)>0 ) // check end
       if(   loop(bp,   0,      dy/16,dx,cs,0,RI)
         >=  loop(bp,dx-1, dy-1-dy/16,dx,cs,0,LE) ) ad=ad*98/100;
-      if(   loop(bp,dx-1,      dy/16,dx,cs,0,LE)
-        >=  loop(bp,   0, dy-1-dy/16,dx,cs,0,RI)
-       &&   loop(bp,dx-1,      dy/16,dx,cs,0,LE)
-        >=  loop(bp,   0,       dy-1,dx,cs,0,RI) ) ad=ad*98/100;
+      MSG(fprintf(stderr,"~S ad=%d",ad);)
+      if(   loop(bp,3*dx/4  ,   0,dy,cs,1,DO) // ToDo: improve!
+         <  loop(bp,  dx/4  ,dy-1,dy,cs,1,UP)
+       &&   loop(bp,3*dx/4-1,   0,dy,cs,0,DO)
+         <  loop(bp,  dx/4+1,dy-1,dy,cs,0,UP) ) ad=ad*98/100;
+      MSG(fprintf(stderr,"~S ad=%d",ad);)
 
       if ( gchar) ad=99*ad/100;
       if (!hchar) ad=99*ad/100;
@@ -200,18 +204,17 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if( num_cross(0, dx-1,dy/2,dy/2,bp,cs) != 1 ) Break;
       if( num_cross(0, dx-1,dy-1,dy-1,bp,cs) != 1
        && num_cross(0, dx-1,dy-2,dy-2,bp,cs) != 1 ) Break;
-      /*  5x7  micr
+      /*  5x7  micr      ocr-a
       
-               ooo
-          .$.  ooo
-          $@.   oo
-          .$.   oo
-          .@.  ooooo
-          .$.  ooooo
-          $@$  ooooo
+               ooo        @@@..
+          .$.  ooo        ..@..
+          $@.   oo        ..@..
+          .$.   oo        ..@..
+          .@.  ooooo      ..@.@
+          .$.  ooooo      ..@.@
+          $@$  ooooo      @@@@@
           
        */
-
       i4=0; // human font
       if( num_cross(0, dx-1,3*dy/4,3*dy/4,bp,cs) != 2 ) { // except ocr-a
         for( y=1; y<dy/2; y++ ){
@@ -221,13 +224,6 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
           if( num_cross(0, dx-1, y  , y  ,bp,cs) != 1 ) i--;
         } if( dy>8 && !i ) Break;
       } else {  // ocr-a-1
-       /*  @@@..
-           ..@..
-           ..@..
-           ..@..
-           ..@.@
-           ..@.@
-           @@@@@  */
         i=  loop(bp,dx/2,0,dy,cs,0,DO);
         if (loop(bp,dx/2,i,dy,cs,1,DO)<dy-1) Break;
         i=  loop(bp,dx  -1,dy-1-dy/16,dx,cs,0,LE);
@@ -235,6 +231,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
         i=  loop(bp,0,dy/16,dx,cs,0,RI);
         if (loop(bp,i,dy/16,dx,cs,1,RI)<dx/2) Break;
         i4=1;
+        MSG(fprintf(stderr,"ocr-a-1 detected ad= %d", ad);)
       }
 
       if( num_cross(0, dx-1, 0  , 0  ,bp,cs) > 1
@@ -260,6 +257,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if(y<7*dy/8) ad=98*ad/100; // serif or ocr-a-1 ?
       if(y<6*dy/8) ad=99*ad/100; /*  MICR E-13B font Jan07 */
       if(y<4*dy/8) Break;
+      MSG(fprintf(stderr,"i12 %d %d ad= %d", i1,i2,ad);)
 // out_x(box1); printf(" i12=%d %d\n",i1,i2);
       x =loop(bp,i2,dy-1,dx,cs,1,LE); j=x;
       x =loop(bp,i2,dy-2,dx,cs,1,LE); if(x>j)j=x; i=j;
@@ -275,6 +273,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if ( i1-i<7*dx/16 ) ad=ad*98/100;
       if ( i1-i<6*dx/16 ) ad=ad*98/100; // 4*dx/8 => 7*dx/16  MICR E-13B font
       if ( i1-i<4*dx/16 ) Break;
+      MSG(fprintf(stderr,"i12 %d %d ad= %d", i1,i2,ad);)
       x =loop(bp,0,dy/2,dx,cs,0,RI); // right distance
       j =loop(bp,x,dy/2,dx,cs,1,RI); // thickness
       if( j>x+(dy+16)/32 ) ad=98*ad/100; // ~l but  MICR E-13B font
@@ -284,8 +283,9 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if( x==j ) if(loop(bp,0,dy/4,dx,cs,0,RI)>x) {  // ~l
         // check micr-1 first before taken as 'l'
         if (loop(bp,dx-1,dy/8,dx,cs,0,LE)<=dx/4
-         && loop(bp,0,3*dy/4,dx,cs,1,RI)<dx-1) ad=97*ad/100;
+         && loop(bp, 0,3*dy/4,dx,cs,1,RI)< dx-1) ad=97*ad/100;
       }
+      MSG(fprintf(stderr,"1l check ad= %d", ad);)
       x=j;
 //      j =loop(bp,0,2,dx,cs,0,RI); if( j>=x ) Break; x=j; // ~l
 //      j =loop(bp,0,   0,dx,cs,0,DO); if( !j  ) Break; // ~7
@@ -301,10 +301,11 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
        && get_bw(x1-dx/4,x1,y1-1,y1,box1->p,cs,1)==1 ) Break; // ~z Jun00
 
       i=loop(bp,  dx/8,0,dy,cs,0,DO);
-      for (y=dy,x=dx/2;x<3*dx/4;x++){ /* get upper end */
+      for (y=dy,x=dx/2;x<3*dx/4;x++){ /* get upper end y */
         j=loop(bp,x,0,dy,cs,0,DO); if (j<y) { y=j; }
       }
-      if(y<dy/2 && y+dy/16>=i) ad=97*ad/100; // ~\tt l ??? ocr-a_1
+      if(y<dy/2 && y+dy/16>=i) ad=98*ad/100; // ~\tt l ??? ocr-a_1
+      MSG(fprintf(stderr,"1l check i= %d y= %d ad= %d", i, y, ad);)
 
       if(   loop(bp,   0,  dy/8,dx,cs,0,RI)
        -(dx-loop(bp,dx-1,7*dy/8,dx,cs,0,LE)) > dx/4 ) Break; // ~/
@@ -330,9 +331,10 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
         if (loop(bp,0,3*dy/4,dx,cs,0,RI)-
             loop(bp,0,dy/2-1,dx,cs,0,RI)>dx/4) ad=95*ad/100; // ~3
         if (loop(bp,dx-1,dy/2-1,dx,cs,0,LE)-
-            loop(bp,dx-1,3*dy/4,dx,cs,0,LE)>dx/8) ad=95*ad/100; // ~3
+            loop(bp,dx-1,3*dy/4,dx,cs,0,LE)>dx/8) ad=99*ad/100; // ~3 ocr-a?
         if (loop(bp,dx-1, dy/16,dx,cs,0,LE)-
             loop(bp,dx-1,  dy/4,dx,cs,0,LE)>dx/8) ad=95*ad/100; // ~23
+        MSG(fprintf(stderr,"23 check ad= %d", ad);)
       }
       /* font 5x9 "2" recognized as "1" */
       i=loop(bp,dx-1-dx/8,dy-1,dy,cs,0,UP);
@@ -343,6 +345,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
           if (2*i>=dx && loop(bp,dx/4,0,dy,cs,0,DO)<dy/2) {
             if (dx<17) ad=98*ad/100;
             if (dx<9)  ad=97*ad/100;
+            MSG(fprintf(stderr,"5x9 2 check ad= %d", ad);)
           }
         }
       }
@@ -354,6 +357,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
         j=loop(bp,0,y,dx,cs,0,RI); if (j<i) i=j;
         if (j>i+dx/8) { break; }
       } if (y>=dy/2) ad=95*ad/100;  // Feb07 care plates, right black border
+      MSG(fprintf(stderr,"ad= %d", ad);)
       
       if (sdata->holes.num > 0) Break; // mini holes should be filtered
       if (!box1->m3 && ad>98) ad=98; else {
@@ -429,6 +433,8 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if (sdata->holes.hole[0].x1 >= dx/2 || sdata->holes.hole[0].y1 >= dy/2)
         Break;
 
+      if (loop(bp,dx-1,   0,dx,cs,0,LE)
+         <loop(bp,dx-1,dy/4,dx,cs,0,LE)-dx/8) Break; // 5x7,5x8 z Jul09
       i1=loop(bp,dx-1-dx/16,0,dy,cs,0,DO);  // Jul00
       i2=loop(bp,     dx/ 2,0,dy,cs,0,DO); if( i2+dy/32>=i1 ) Break; // ~z
       i1=loop(bp,dx-1,dy-3*dy/16,dx,cs,0,LE);
@@ -467,6 +473,10 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
         3OO4   3OO4    
 */
 
+      // ToDo: replace by vector code (get point on line at dy/4)
+      if (loop(bp,dx-1,   0,dx,cs,0,LE)
+         <loop(bp,dx-1,dy/4,dx,cs,0,LE)-dx/8) Break; // 5x7,5x8 z Jul09
+
       /* get a point on the inner low left side of the J */
       i =box1->num_frame_vectors[0] - 1;
       /* rightmost point on upper left side */
@@ -508,7 +518,7 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if (box1->frame_vector[i5][1]
          -box1->frame_vector[i6][1]<dy/4) Break; // ~5
       if (box1->frame_vector[i1][1]>y0+dy/2) Break; // not to low
-      if (box1->frame_vector[i1][0]>x0+dx/8) Break;
+      if (box1->frame_vector[i1][0]>x0+dx/8+dx/16) Break; // slanted ?
       if (box1->frame_vector[i2][1]>(y0+  y1)/2) Break; 
       if (box1->frame_vector[i2][1]>(5*y0+3*y1)/8) ad=99*ad/100; 
       MSG( fprintf(stderr,"ad %d", ad); )
@@ -518,13 +528,14 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if (box1->frame_vector[i3][0]>(3*x0+x1)/4) Break;
       if (box1->frame_vector[i3][0]>(7*x0+x1)/8) ad=99*ad/100;
       MSG( fprintf(stderr,"ad %d", ad); )
+      /* check lowest left point */
       if (box1->frame_vector[i3][1]<(y0+3*y1)/4) Break;
-      if (box1->frame_vector[i3][1]>(y0+7*y1)/8) ad=99*ad/100;
+      if (box1->frame_vector[i3][1]<(y0+7*y1)/8) ad=99*ad/100;
       MSG( fprintf(stderr,"ad %d", ad); )
       /* check lower leftmost point from right side */
       if (box1->frame_vector[i5][0]>(x0+2*x1)/3) Break;
       if (box1->frame_vector[i5][0]>(x0+  x1)/2) ad=98*ad/100;
-      if (box1->frame_vector[i5][0]>(2*x0+x1)/3) ad=99*ad/100;
+      if (box1->frame_vector[i5][0]>(2*x0+2+x1)/3) ad=99*ad/100; /* 9x10 2 */
       MSG( fprintf(stderr,"ad %d", ad); )
       if (box1->frame_vector[i5][1]<(3*y0+5*y1)/8) Break;
       if (box1->frame_vector[i5][1]<(y0+3*y1)/4) ad=99*ad/100;
@@ -554,8 +565,70 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
    // --- test 3 -------
    for(ad=d=100;dx>3 && dy>4;){	// dy<=dx nicht perfekt! besser mittleres
 				// min-suchen fuer m
+      int i1, i2, i3, i4, i5, i6, i7, i8;  // line derivation + corners
       DBG( char c_ask='3'; )
       if (sdata->holes.num > 1) Break; /* be tolerant */
+      if (sdata->holes.num > 0) ad=98*ad/100; /* be tolerant */
+      if (4*dx<dy) ad=98*ad/100; // to tall 1:2 - 1:3 is usual 
+      // --- vector based code ---
+      /* half distance to the center */
+      d=2*sq(128/4);
+      /* now we check for the lower ends, must be near to the corner */
+      if (aa[1][2]>d/1) Break;  /* [2] = distance, ~7... */
+      if (aa[2][2]>d/1) Break;  /* [2] = distance, ~r... */
+      if (aa[0][2]>d/1) Break;  /* [2] = distance, ~d... */
+      if (aa[3][2]>d/1) Break;  /* [2] = distance, ~bhk... */
+/*
+    type A       B      C
+                    
+        1OO8   1OO   1OO8
+           O      8    2    <- 7,8 
+           2      2   7      
+ 1-5->  3OO7    37   3OO
+           4      4     4
+           O      6     6   <- 6
+        5OO6   5OO   5OO
+*/
+      /* rightmost point on upper left side */
+      i2=nearest_frame_vector(box1, aa[0][3], aa[1][3], x1, y0+3*dy/16);
+      /* rightmost point on lower left side */
+      i4=nearest_frame_vector(box1, aa[0][3], aa[1][3], x1, y1-dy/4);
+      /* leftmost point on middle left side */
+      i3=nearest_frame_vector(box1,       i2,       i4, x0, y0+dy/2);
+      /* upper leftmost vector */
+      i1=nearest_frame_vector(box1, aa[0][3], i2, x0-dx, (y0+y1)/2);
+      i5=aa[1][3]; // points to vector point in point list
+      i6=aa[2][3];
+      i8=aa[3][3];
+      /* leftmost point on middle right side */
+      i7=nearest_frame_vector(box1,       i6,       i8, x0   , y0+dy/2);
+      /* which type? ToDo: have a more sure algorithm */
+      if (box1->frame_vector[i7][0]>=x1-  dx/4
+       && box1->frame_vector[i6][0]>=x1-  dx/8 // ToDo: ...
+       && box1->frame_vector[i6][1]>=y1-  dy/8) {
+        MSG(fprintf(stderr,"7-segment-type");)   
+      } else { /* regular-book-type */
+      }
+      // ToDo: output no=(x,y)
+      MSG(fprintf(stderr,"i1-8 %d %d %d %d %d %d %d %d",i1,i2,i3,i4,i5,i6,i7,i8);)
+      // if (i5==i6) Break; // ~+
+  
+      // i2 = upper left gap ) , i3 = middle left <
+      if (box1->frame_vector[i2][0]
+         -box1->frame_vector[i3][0]<dx/4) Break; // video samples
+      if (box1->frame_vector[i4][0]
+         -box1->frame_vector[i3][0]<dx/4) Break; // video samples
+      if (box1->frame_vector[i4][0]
+         -box1->frame_vector[i5][0]<dx/2) Break; // video samples
+      if (box1->frame_vector[i2][0]
+         -box1->frame_vector[i1][0]<dx/2) Break; // video samples
+      if (box1->frame_vector[i1][1]>y0+dy/2) Break; // not to low
+      if (box1->frame_vector[i1][0]>x0+dx/4+dx/16) Break; // slanted?
+      if (box1->frame_vector[i5][1]<y1-dy/2) Break; // not to high
+      if (box1->frame_vector[i5][0]>x0+dx/4) Break;
+      // ToDo ....
+
+      // --- pixel based old code ---
       // if( get_bw(x0+dx/2,x0+dx/2,y0,y0+dy/4,box1->p,cs,1) == 0 ) Break; // ~4
       // if( get_bw(x0+dx/2,x0+dx/2,y1-dy/8,y1,box1->p,cs,1) == 0 ) Break; // ~4
       // if( num_cross(x0+dx/2,x0+dx/2,y0     ,y1,box1->p,cs) < 2 ) Break;
@@ -574,11 +647,15 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if( loop(bp,dx-1,2*dy/3,dy,cs,0,LE)>dy/4 ) Break;
       if( loop(bp,dx-1,3*dy/4,dy,cs,0,LE)>dy/2 ) Break; // ~2 Feb06
       if( loop(bp,dx-1,7*dy/8,dy,cs,0,LE)>dy/2 ) Break; // ~2 Feb06
-      // search upper right half circle
+      // search upper right half circle (may fail on 4x5 font)
       for( i3=x=0,i1=y=dy/5;y<dy/2;y++ ){
         i=loop(bp,0,y,dx,cs,0,RI);
         if (i>x) { i3=x=i; i1=y; }
-      } i3--; if (i3<dx/3 && i3+1+loop(bp,i3+1,i1,dx,cs,1,RI)<3*dx/4) Break;
+      } i3--;
+      if( loop(bp,i3,i1,1,cs,0,UP)==1 ) { // find hidden gap in tiny fonts
+        i1--; i3+=loop(bp,i3,i1,dx,cs,0,RI)-1;
+      }
+      if (i3<dx/3 && i3+1+loop(bp,i3+1,i1,dx,cs,1,RI)<3*dx/4) Break;
       if (loop(bp,dx-1,i1,dx,cs,0,LE)>1+dx/8) ad=ad*99/100; // ~1 with a pixel
       // search lower right half circle
       for( i4=x=0,i2=y=dy-1-dy/8;y>=dy/2;y-- ){
@@ -596,11 +673,13 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if (xa>1+dx/8 // noLCD
         && xa<=loop(bp,dx-1,i1,dx,cs,0,LE)) ad=ad*99/100; // ~1 with a pixel
       
-
-      if( get_bw(i3,i3,i1,i2  ,bp,cs,1) != 1 ) Break;
+      // upper left gap = (i3,i1)
+      // lower left gap = (i4,i2)
+      MSG(fprintf(stderr,"left white gaps (%d,%d) (%d,%d)",i3,i1,i4,i2);)
+      if( get_bw(i3,i3,i1,i2  ,bp,cs,1) != 1 ) Break; // no hor. middle line?
       if( get_bw(i4,i4,i1,i2  ,bp,cs,1) != 1 ) Break;
-      if( get_bw(i3,i3,0 ,i1  ,bp,cs,1) != 1 ) Break;
-      if( get_bw(i4,i4,i1,dy-1,bp,cs,1) != 1 ) Break;  // m like
+      if( get_bw(i3,i3,0 ,i1  ,bp,cs,1) != 1 ) Break; // no upper bow?
+      if( get_bw(i4,i4,i2,dy-1,bp,cs,1) != 1 ) Break; // no lower bow?
       // hole is only allowed in beauty fonts
       // if( num_hole( x0, x1,      y0,      y1,box1->p,cs,NULL) > 0 ) // there is no hole
       // if( num_hole( x0, x0+dx/2, y0, y0+dy/2,box1->p,cs,NULL) == 0 ) // except in some beauty fonts
@@ -618,9 +697,13 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       DBG( wchar_t c_ask='4'; )
       if (sdata->holes.num > 1) Break; /* no or one hole */
       /* half distance to the center */
-      d=2*sq(128/4);
+      d=2*sq(128/4); /* 2048 */
       /* now we check for the lower left end, must be far away */
-      if (aa[1][2]<d/8) Break;  /* [2] = distance, ~ABDEF... */
+      /* lowest is 144 for 9x10 screen font (Apr2009) */
+      if (aa[1][2]<d/16) {  /* Apr09: d/8=256 to d/16=128 */
+        MSG( fprintf(stderr," low-left-dist= %d < max= %d", aa[1][2], d); )
+        Break;  /* [2] = distance, ~ABDEF... */
+      }
       /* searching for 4 notches between neighbouring ends */
 
 /*
@@ -631,6 +714,8 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
         2OO3   O 5    O O    O O   <- 7 6
            O   2O3O  2OO3   2OO3O
            4     4      4      4
+           
+     y4-y3 should be significant (bigger y3-y6)?
 */
 
       /* Warning: aa0 can be left upper or left lower point for type B */
@@ -657,6 +742,10 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if (box1->num_frames>1) {  // type C D
         i = box1->num_frame_vectors[0] - 1; // end outer loop
         j = box1->num_frame_vectors[1] - 1; // end inner loop
+        if (box1->num_frames>2) { // see font2.png, 2nd one pixel hole
+          j = box1->num_frame_vectors[2] - 1; // end inner loop
+          ad=99*ad/100; // little bit unsure
+        }
         i6=nearest_frame_vector(box1, i+1, j, x1, y1);
         i7=nearest_frame_vector(box1, i+1, j, x0, y1);
         if (box1->frame_vector[i1][0]
@@ -692,8 +781,17 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       if (box1->frame_vector[i4][1]
          -box1->frame_vector[i2][1]<dy/6) ad=99*ad/100;
       /* min. distance of the horizontal bar to the ground */
+      /* y4-y3 should be significant (bigger y3-y6)? */
       if (box1->frame_vector[i4][1]
          -box1->frame_vector[i3][1]<1+dy/16) Break;
+      if ((box1->frame_vector[i4][1]
+          -box1->frame_vector[i3][1])*2<=
+          (box1->frame_vector[i3][1]
+          -box1->frame_vector[i6][1])) Break; // 090728 gas_meter (flat-ulike)
+      if ((box1->frame_vector[i4][1]
+          -box1->frame_vector[i3][1])<
+          (box1->frame_vector[i3][1]
+          -box1->frame_vector[i6][1])) ad=99*ad/100;
       if (box1->frame_vector[i4][1]
          -box1->frame_vector[i3][1]<dy/6) ad=99*ad/100; /* tall chars */
       if (box1->frame_vector[i4][1]
@@ -1029,12 +1127,13 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
    }
    // --- test 9 \it g ---------------------------------------------------
    /* 
-    *    lcd  micr
-    *    ooo  ooo
-    *    o o  o o
-    *    ooo  ooo
-    *      o    o
-    *    ooo    o
+    * 
+    *    lcd  micr round
+    *    ooo  ooo  ooo
+    *    o o  o o  o o
+    *    ooo  ooo  ooo
+    *      o    o    o
+    *    ooo    o   o
     */
    for(ad=d=100;dx>2 && dy>4;){     // dx>1 dy>2*dx
       DBG( char c_ask='9'; )
@@ -1088,9 +1187,11 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
       i2=loop(bp,dx-1,dy/2     ,dx,cs,0,LE); if(i1+i3-2*i2<-1-dx/16) Break; // konvex
       i1=loop(bp,dx-1,dy/4     ,dx,cs,0,LE); if(i1>dx/2) Break;
       i3=loop(bp,dx-1,dy-1-dy/8,dx,cs,0,LE);
-      for(y=dy/4;y<dy-1-dy/4;y++){
+      for(y=dy/4;y<dy-1-dy/4;y++){ // may fail on type=round
         i2=loop(bp,dx-1,y,dx,cs,0,LE);
-        if(i1+i3-2*i2<-1-dx/16) break;  // konvex from right ~g ~3
+        // konvex from right ~g ~3 Jul09
+        if(i2>i1+(i3-i1)*(2*y-dy/2)/dy+dx/16) break;
+        // MSG(fprintf(stderr," y i2 %d %d %d",y,i2,i1+(i3-i1)*(2*y-dy/2)/dy);)
       } if(y<dy-1-dy/4) Break;
       x=loop(bp,dx  -1,6*dy/8,dx,cs,0,LE); if(x>0){
         x--; // robust
@@ -1105,8 +1206,13 @@ wchar_t ocr0n(ocr0_shared_t *sdata){
           -loop(bp,dx-1,dy/16,dx,cs,0,LE)>dx/6) Break; // ~ serif yY
           
       if (box1->m3) {
-        if( gchar) ad=99*ad/100;  /* unsure */
-        if(!hchar) ad=99*ad/100;  /* unsure */
+        if ( gchar) ad=99*ad/100;  /* unsure (italic g)? */
+        if (box1->m2 && (!gchar) && y1 > box1->m3){
+          ad=99*ad/100;
+          if (box1->m4-box1->m3<3) ad=99*ad/100;
+          // if (!hchar) ad = 99*ad/100;
+        }
+        if (!hchar) ad=99*ad/100;  /* unsure */
       } else { if (ad==100) ad=99; } /* not 100% sure */
       Setac(box1,(wchar_t)'9',ad);
       break;
