@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2007  Joerg Schulenburg
+Copyright (C) 2000-2009  Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -205,10 +205,12 @@ otsu (unsigned char *image, int rows, int cols,
   // debug code to display thresholding values
   if ( vvv & 1 )
   fprintf(stderr,"# threshold: Value = %d gmin=%d gmax=%d cmax=%d"
-                 " i= %d %d\n",
+                 " b/w= %d %d\n",
      thresholdValue, gmin, gmax, maxc, i1, i2);
 
-  if (i1>=4*i2) { // black>=4*white, obviously black is background
+  // this is a primitive criteria for inversion and should be improved
+  // old: i1 >= 4*i2, but 0811qemu1.png has a bit above 1/4 
+  if (2*i1 > 7*i2) { // more black than white, obviously black is background
     if ( vvv & 1 )
       fprintf(stderr,"# threshold: invert the image\n");
     // we do inversion here (no data lost)
@@ -265,10 +267,11 @@ thresholding (unsigned char *image, int rows, int cols,
   /* b/w: min=0,tresh=1,max=1 v0.43 */
   // actually performs the thresholding of the image...
   //  later: grayvalues should also be used, only rescaling threshold=160=0xA0
+  // sometimes images have no contrast (thresholdValue == gmin)
   for (i = y0; i < y0+dy; i++) {
     np = &image[i*cols+x0];
     for (j = x0; j < x0+dx; j++) {
-      *np = (unsigned char) (*np >= thresholdValue ?
+      *np = (unsigned char) (*np >= thresholdValue || thresholdValue == gmin ?
          (255-(gmax - *np)* 80/(gmax - thresholdValue + 1)) :
          (  0+(*np - gmin)*150/(thresholdValue - gmin    )) );
       if(*np > nmax) nmax=*np;
