@@ -1,6 +1,6 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000-2007 Joerg Schulenburg
+Copyright (C) 2000-2009 Joerg Schulenburg
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -488,17 +488,23 @@ int remove_melted_serifs( pix *pp ){
       j1+=loop(pp,j1,y0  ,x1-x0,cs,0,RI);
       x  =loop(pp,j1,y0  ,x1-x0,cs,1,RI);	       if(j1+x>x1+1) break;
       y  =loop(pp,j1,y0+1,x1-x0,cs,1,RI); if(y>x) x=y; if(j1+x>x1+1) break;
-      /* measure mean thickness of serif */
+      /* measure mean thickness of serif pos: (j1,y0)-(j1+x,y0) */
       for(j2=j3=j4=0,i2=j1;i2<j1+x;i2++){
-        i3 =loop(pp,j1,y0   ,y1-y0,cs,0,DO); if(8*i3>y1-y0) break;
-        i3+=loop(pp,j1,y0+i3,y1-y0,cs,1,DO); if(8*i3>y1-y0) break;
-        if(8*i3<y1-y0){ j2+=i3; j3++; }
-      } if(j3==0){ j1+=x; continue; } 
-      y = y0+(j2+j3-1)/j3+(y1-y0+1)/32;
+        /* 2009-07: bug, j1 used instead of i2 */
+        i3 =loop(pp,i2,y0   ,y1-y0,cs,0,DO); if(8*i3>y1-y0) break;
+        i3+=loop(pp,i2,y0+i3,y1-y0,cs,1,DO); if(8*i3>y1-y0) continue;
+        if(8*i3<y1-y0){ j2+=i3; j3++; } /* sum vert. thickness */
+      } if(j3==0){ j1+=x; continue; }   /* no serif, skip this object */
+      y = y0+(j2+j3-1)/j3+(y1-y0+1)/32; /* y0 + mean thickness + dy/32 + 1 */
+      if (vvv&1)
+        fprintf(stderr, "\n#  upper serif x0,y0,j1-x0+x,y-y0 %4d %4d %2d+%2d %2d",
+          x0,y0,j1-x0,x,y-y0);
 
       /* check if really melted serifs */
-      if( loop(pp,j1,y,x1-x0,cs,0,RI)<1 ) { j1+=x; continue; }
+      if (loop(pp,j1,y,x1-x0,cs,0,RI)<1) { j1+=x; continue; }
       if(num_cross(j1 ,j1+x,y,y,pp,cs) < 2 ){ j1+=x;continue; }
+      if (vvv&1)
+        fprintf(stderr, " ok1");
       j2 = j1 + loop(pp,j1,y,x1-x0,cs,0,RI);
       j2 = j2 + loop(pp,j2,y,x1-x0,cs,1,RI);
       i3 =      loop(pp,j2,y,x1-x0,cs,0,RI); if(i3<2){j1+=x;continue;}
@@ -519,6 +525,9 @@ int remove_melted_serifs( pix *pp ){
 	  out_x(box2);
 	  fprintf(stderr,"# melted serifs corrected on %d %d j1=%d j3=%d",
 	    j2-x0, y, j1-x0, j3-x0);
+	  // ToDo: vector cut with line from xa,ya to xb,yb
+	  //    two frames of double melted MN become one frame if cut one
+	  //    of the melted serifs (new function cut_frames_at_line())
 	}
 	for(xb=0,xa=0;xa<(x1-x0+4)/8;xa++){ /* detect vertical gap */
 	  i3=y1; 
@@ -534,7 +543,7 @@ int remove_melted_serifs( pix *pp ){
 	  box3=malloc_box(box2);
 	  box3->x1=j2-1;
 	  box2->x0=j2+1; x1=box2->x1;
-	  cut_box(box2); /* cut vectors outside the box */
+	  cut_box(box2); /* cut vectors outside the box, see box.c */
 	  cut_box(box3);
 	  box3->num=JOB->res.numC;
 	  list_ins(&(JOB->res.boxlist),box2,box3); JOB->res.numC++; ii++; /* insert box3 before box2 */
@@ -556,15 +565,20 @@ int remove_melted_serifs( pix *pp ){
       y  =loop(pp,j1,y1-1,x1-x0,cs,1,RI); if(y>x) x=y; if(j1+x>x1+1) break;
       /* measure mean thickness of serif */
       for(j2=j3=j4=0,i2=j1;i2<j1+x;i2++){
-        i3 =loop(pp,j1,y1   ,y1-y0,cs,0,UP); if(8*i3>y1-y0) break;
-        i3+=loop(pp,j1,y1-i3,y1-y0,cs,1,UP); if(8*i3>y1-y0) break;
+        /* 2009-07: bug, j1 used instead of i2 */
+        i3 =loop(pp,i2,y1   ,y1-y0,cs,0,UP); if(8*i3>y1-y0) break;
+        i3+=loop(pp,i2,y1-i3,y1-y0,cs,1,UP); if(8*i3>y1-y0) continue;
         if(8*i3<y1-y0){ j2+=i3; j3++; }
       } if(j3==0){ j1+=x; continue; } 
       y = y1-(j2+j3-1)/j3-(y1-y0+1)/32;
+      if (vvv&1)
+        fprintf(stderr, "\n#  lower serif x0,y0,j1-x0+x,y1-y %4d %4d %2d+%2d %2d",
+          x0,y0,j1-x0,x,y1-y);
 
       /* check if really melted serifs */
       if( loop(pp,j1,y,x1-x0,cs,0,RI)<1 ) { j1+=x; continue; }
       if(num_cross(j1 ,j1+x,y,y,pp,cs) < 2 ){ j1+=x;continue; }
+      if (vvv&1) fprintf(stderr, " ok1");
       j2 = j1 + loop(pp,j1,y,x1-x0,cs,0,RI);
       j2 = j2 + loop(pp,j2,y,x1-x0,cs,1,RI);
       i3 =      loop(pp,j2,y,x1-x0,cs,0,RI); if(i3<2){j1+=x;continue;}
