@@ -1,23 +1,23 @@
 /*
 This is a Optical-Character-Recognition program
-Copyright (C) 2000  Joerg Schulenburg
+Copyright (C) 2000-2007  Joerg Schulenburg
 
-       The character codes in this file are Copyright (c) 1991-1999 Unicode, Inc.
-       All Rights reserved.
+   The character codes in this file are Copyright (c) 1991-1999 Unicode, Inc.
+   All Rights reserved.
 
-       This file is provided as-is by Unicode, Inc. (The Unicode Consortium).
-       No claims are made as to fitness for any particular purpose.  No
-       warranties of any kind are expressed or implied.  The recipient
-       agrees to determine applicability of information provided.  If this
-       file has been provided on optical media by Unicode, Inc., the sole
-       remedy for any claim will be exchange of defective media within 90
-       days of receipt.
+   This file is provided as-is by Unicode, Inc. (The Unicode Consortium).
+   No claims are made as to fitness for any particular purpose.  No
+   warranties of any kind are expressed or implied.  The recipient
+   agrees to determine applicability of information provided.  If this
+   file has been provided on optical media by Unicode, Inc., the sole
+   remedy for any claim will be exchange of defective media within 90
+   days of receipt.
 
-       Unicode, Inc. hereby grants the right to freely use the information
-       supplied in this file in the creation of products supporting the
-       Unicode Standard, and to make copies of this file in any form for
-       internal or external distribution as long as this notice remains
-       attached.
+   Unicode, Inc. hereby grants the right to freely use the information
+   supplied in this file in the creation of products supporting the
+   Unicode Standard, and to make copies of this file in any form for
+   internal or external distribution as long as this notice remains
+   attached.
 
 For the rest of the file, the following applies:
 
@@ -1225,6 +1225,26 @@ const char *decode(wchar_t c, FORMAT type);
 #define UP_RIGHT_DIAGONAL_ELLIPSIS					0x22F0
 #define DOWN_RIGHT_DIAGONAL_ELLIPSIS					0x22F1
 
+/* Optical Character Recognition in Unicode (see wikipedia/OCR)
+ * range: 0x2440-0x245F
+ */
+#define OCR_Hook                         0x2440
+#define OCR_Chair                        0x2441
+#define OCR_Fork                         0x2442
+#define OCR_Inverted_Fork                0x2443
+#define OCR_Belt_Buckle                  0x2444
+#define OCR_Bow_Tie                      0x2445
+
+/* the following 4 MICR chars (magnetic ink character recognition)
+ * They look like:  |:  ,|'  ||'  |||  (known also as MICR-A,B,C,D)
+ */
+#define OCR_Branch_Bank_Identification   0x2446
+#define OCR_Amount_Of_Check              0x2447
+#define OCR_Customer_Account_Number      0x2448
+#define OCR_Dash                         0x2449
+
+#define OCR_Double_Backslash             0x244A
+
 /* latin ligatures */
 #define LATIN_SMALL_LIGATURE_FF						0xFB00
 #define LATIN_SMALL_LIGATURE_FI						0xFB01
